#!/usr/bin/env Rscript
rm(list=ls(all=TRUE))
rootpath=...
setwd(paste(rootpath,"Analysis/Input",sep=""))
getwd()
library(plyr)
library(reshape)

# kuznets/kendrick and nipa - nominal
# import, merge, apply ratio
Kuz_Curr_VIII <- read.csv("Kuz_Curr_VIII.csv",skip=0)
tbl_1889_09_consnom_v0a <- subset(Kuz_Curr_VIII,Year<=1929)
tbl_1889_09_consnom_v0a$NCND_KUZ_LVL = tbl_1889_09_consnom_v0a$Perishables+tbl_1889_09_consnom_v0a$Semi.durables
tbl_1889_09_consnom_v0a$NCS_KUZ_LVL = tbl_1889_09_consnom_v0a$Services+tbl_1889_09_consnom_v0a$Kendrick.Adjustment
tbl_1889_09_consnom_v0a = subset(tbl_1889_09_consnom_v0a, select=c("Year","NCND_KUZ_LVL","NCS_KUZ_LVL"))
tbl_1929_ratio_a <- subset(tbl_1889_09_consnom_v0a,Year==1929)
tbl_1889_09_consnom_v0a <- subset(tbl_1889_09_consnom_v0a,Year<1929)

NIPA_10105_Ann <- read.csv("10105 Ann.csv",skip=8)
tbl_1889_09_consnom_v0b <- subset(NIPA_10105_Ann,select=c("Year","Nondurable.goods","Services"))
tbl_1889_09_consnom_v0b <- rename(tbl_1889_09_consnom_v0b,c(Nondurable.goods="NCND_KUZ_LVL",Services="NCS_KUZ_LVL"))
tbl_1929_ratio_b <- subset(tbl_1889_09_consnom_v0b,Year==1929)

tbl_1929_ratio <- merge(tbl_1929_ratio_a,tbl_1929_ratio_b,by="Year")
tbl_1929_ratio$ratioknnd = tbl_1929_ratio$NCND_KUZ_LVL.y/tbl_1929_ratio$NCND_KUZ_LVL.x
tbl_1929_ratio$ratiokns = tbl_1929_ratio$NCS_KUZ_LVL.y/tbl_1929_ratio$NCS_KUZ_LVL.x

tbl_1929_ratio <- subset(tbl_1929_ratio,select=c("ratioknnd","ratiokns"))
tmp <- tbl_1929_ratio

# export ratios
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
sink(file="s001.tbl_1929_ratio.txt")
tbl_1929_ratio
sink(NULL)

# continue analysis

setwd(paste(rootpath,"Analysis/Input",sep=""))
getwd()

for(i in 1:(1928-1889)){ 	
	tbl_1929_ratio <- rbind(tbl_1929_ratio,tmp)
}

tbl_1929_ratio$Year <- 1889:1928

tbl_1889_09_consnom_v0a <- merge(tbl_1889_09_consnom_v0a,tbl_1929_ratio,by="Year")
tbl_1889_09_consnom_v0a$NCND_KUZ_LVL = tbl_1889_09_consnom_v0a$NCND_KUZ_LVL*tbl_1889_09_consnom_v0a$ratioknnd 
tbl_1889_09_consnom_v0a$NCS_KUZ_LVL = tbl_1889_09_consnom_v0a$NCS_KUZ_LVL*tbl_1889_09_consnom_v0a$ratiokns
tbl_1889_09_consnom_v0a = subset(tbl_1889_09_consnom_v0a, select=c("Year","NCND_KUZ_LVL","NCS_KUZ_LVL"))

tbl_1889_09_consnom_v0 <- rbind(tbl_1889_09_consnom_v0a,tbl_1889_09_consnom_v0b)

# import population, merge, compute per capita and growth

POP1 <- read.csv("POP1.csv",skip=5)
POP1 <- subset(rename(POP1,c(X="Year",Thousand="pop")), select=c("Year","pop"))
POP1 <- subset(POP1,Year<=2000)

POP2 <- read.csv("POP2.csv",skip=0)
POP2 <- subset(POP2,Year>=2001)
POP2$pop = POP2$pop/1000

POP <- rbind(POP1,POP2)
POP$pop = POP$pop/1000

tbl_1889_09_consnom_v0 <- merge(tbl_1889_09_consnom_v0,POP,by="Year")
tbl_1889_09_consnom_v0$NCNDPER_KUZ_LVL = 1000*tbl_1889_09_consnom_v0$NCND_KUZ_LVL/tbl_1889_09_consnom_v0$pop
tbl_1889_09_consnom_v0$NCSPER_KUZ_LVL = 1000*tbl_1889_09_consnom_v0$NCS_KUZ_LVL/tbl_1889_09_consnom_v0$pop

tbl_1889_09_consnom_v0$NCNDPER_KUZ_LVL_LEAD=c(tail(tbl_1889_09_consnom_v0$NCNDPER_KUZ_LV,-1),NA)
tbl_1889_09_consnom_v0$NCNDPER_KUZ_GRW=tbl_1889_09_consnom_v0$NCNDPER_KUZ_LVL_LEAD/tbl_1889_09_consnom_v0$NCNDPER_KUZ_LVL-1

tbl_1889_09_consnom_v0$NCSPER_KUZ_LVL_LEAD=c(tail(tbl_1889_09_consnom_v0$NCSPER_KUZ_LV,-1),NA)
tbl_1889_09_consnom_v0$NCSPER_KUZ_GRW=tbl_1889_09_consnom_v0$NCSPER_KUZ_LVL_LEAD/tbl_1889_09_consnom_v0$NCSPER_KUZ_LVL-1

tbl_1889_09_consnom_v0$NCNDSPER_KUZ_GRW=(tbl_1889_09_consnom_v0$NCNDPER_KUZ_LVL_LEAD+tbl_1889_09_consnom_v0$NCSPER_KUZ_LVL_LEAD)/(tbl_1889_09_consnom_v0$NCNDPER_KUZ_LVL+tbl_1889_09_consnom_v0$NCSPER_KUZ_LVL)-1

# export results
kuznets_kendrick_nipa_nominal_v0 <- tbl_1889_09_consnom_v0
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
save(kuznets_kendrick_nipa_nominal_v0,file="s001.kuznets_kendrick_nipa_nominal_v0.RData")
