#!/usr/bin/env Rscript
rm(list=ls()[!grepl('^rootpath$',ls())])
setwd(paste(rootpath,"Analysis/Input",sep=""))
getwd()
library(reshape)

# alternative, kuznets/kendrick and nipa - nominal
# construct non-durables real 1899-1918

# import/merge: (1) perishables, domestic consumption at cost to producers, current prices; and (2) price indices (1913=100)
# for groups 1a, 1b, 2, 3, 4, 5a and 5b from shaw (1947)

# (1) perishables, domestic consumption at cost to producers, current prices
Shaw_1a <- read.csv("Shaw_1a.csv",skip=0)
Shaw_1a <- subset(Shaw_1a,select=c("Year","Domestic.Consumption"))
Shaw_1a <- rename(Shaw_1a,c(Domestic.Consumption="cons1a"))

Shaw_1b <- read.csv("Shaw_1b.csv",skip=0)
Shaw_1b <- subset(Shaw_1b,select=c("Year","Domestic.Consumption"))
Shaw_1b <- rename(Shaw_1b,c(Domestic.Consumption="cons1b"))

Shaw_2 <- read.csv("Shaw_2.csv",skip=0)
Shaw_2 <- subset(Shaw_2,select=c("Year","Domestic.Consumption"))
Shaw_2 <- rename(Shaw_2,c(Domestic.Consumption="cons2"))

Shaw_3 <- read.csv("Shaw_3.csv",skip=0)
Shaw_3 <- subset(Shaw_3,select=c("Year","Domestic.Consumption"))
Shaw_3 <- rename(Shaw_3,c(Domestic.Consumption="cons3"))

Shaw_4 <- read.csv("Shaw_4.csv",skip=0)
Shaw_4 <- subset(Shaw_4,select=c("Year","Domestic.Consumption"))
Shaw_4 <- rename(Shaw_4,c(Domestic.Consumption="cons4"))

Shaw_5a <- read.csv("Shaw_5a.csv",skip=0)
Shaw_5a <- subset(Shaw_5a,select=c("Year","Domestic.Consumption"))
Shaw_5a <- rename(Shaw_5a,c(Domestic.Consumption="cons5a"))

Shaw_5b <- read.csv("Shaw_5b.csv",skip=0)
Shaw_5b <- subset(Shaw_5b,select=c("Year","Domestic.Consumption"))
Shaw_5b <- rename(Shaw_5b,c(Domestic.Consumption="cons5b"))

Shaw_Perishables <- merge(Shaw_1a,Shaw_1b,by="Year")
Shaw_Perishables <- merge(Shaw_Perishables,Shaw_2,by="Year")
Shaw_Perishables <- merge(Shaw_Perishables,Shaw_3,by="Year")
Shaw_Perishables <- merge(Shaw_Perishables,Shaw_4,by="Year")
Shaw_Perishables <- merge(Shaw_Perishables,Shaw_5a,by="Year")
Shaw_Perishables <- merge(Shaw_Perishables,Shaw_5b,by="Year")

# (2) price indices (1913=100) for groups 1a, 1b, 2, 3, 4, 5a and 5b from shaw (1947)
Shaw_price_indices1a_5a <- read.csv("Shaw_price_indices1a-5a.csv",skip=0)
Shaw_price_indices1a_5a <- by(Shaw_price_indices1a_5a,Shaw_price_indices1a_5a$Year,head,n=1)
Shaw_price_indices1a_5a <- do.call("rbind",as.list(Shaw_price_indices1a_5a))

# creating a price index for 5b group
Shaw_price_indices5b_0 <- read.csv("Shaw_price_indices5b.csv",skip=1)
Shaw_price_indices5b_0 <- subset(Shaw_price_indices5b_0,select=c("Year","Shipments.000.Net.Tons","Price.per.Net.Tons","Destinate.for.sale.to.ultimate.consumers..000","Av..Price.per.net.ton.prepared.sizes.at.mine","Production.000.Net.Tons","Value..000"))
Shaw_price_indices5b_1 <- rename(Shaw_price_indices5b_0,c(Shipments.000.Net.Tons="q1",Price.per.Net.Tons="p1",Destinate.for.sale.to.ultimate.consumers..000="q2",Av..Price.per.net.ton.prepared.sizes.at.mine="p2",Value..000="rev3",Production.000.Net.Tons="q3"))
Shaw_price_indices5b_1$p3 = Shaw_price_indices5b_1$rev3/Shaw_price_indices5b_1$q3
varnames_drop <- names(Shaw_price_indices5b_1) %in% c("rev3")
Shaw_price_indices5b_1 <- Shaw_price_indices5b_1[!varnames_drop]

Shaw_price_indices5b_1913_values <- subset(Shaw_price_indices5b_1,Year==1913)
varnames_drop <- names(Shaw_price_indices5b_1913_values) %in% c("Year")
Shaw_price_indices5b_1913_values <- Shaw_price_indices5b_1913_values[!varnames_drop]

tmp <- Shaw_price_indices5b_1913_values
for(i in 1:(1919-1899)){ 	
	Shaw_price_indices5b_1913_values <- rbind(Shaw_price_indices5b_1913_values,tmp)
}
Shaw_price_indices5b_1913_values$Year <- 1899:1919
Shaw_price_indices5b_1913_values <- rename(Shaw_price_indices5b_1913_values,c(p1="p1_1913",q1="q1_1913",p2="p2_1913",q2="q2_1913",q3="q3_1913",p3="p3_1913"))
Shaw_price_indices5b_2 <- merge(Shaw_price_indices5b_1,Shaw_price_indices5b_1913_values,by="Year")

attach(Shaw_price_indices5b_2)
Shaw_price_indices5b_2$num[Year<=1906 | Year==1910] <- p1[Year<=1906 | Year==1910]*q1_1913[Year<=1906 | Year==1910] + p2[Year<=1906 | Year==1910]*q2_1913[Year<=1906 | Year==1910]
Shaw_price_indices5b_2$num[Year<=1909 & Year>=1907] <- p1[Year<=1909 & Year>=1907]*q1_1913[Year<=1909 & Year>=1907] + p2[Year<=1909 & Year>=1907]*q2_1913[Year<=1909 & Year>=1907] + p3[Year<=1909 & Year>=1907]*q3_1913[Year<=1909 & Year>=1907]
Shaw_price_indices5b_2$num[Year<=1919 & Year>=1911] <- p1[Year<=1919 & Year>=1911]*q1_1913[Year<=1919 & Year>=1911] + p2[Year<=1919 & Year>=1911]*q2_1913[Year<=1919 & Year>=1911] + p3[Year<=1919 & Year>=1911]*q3_1913[Year<=1919 & Year>=1911]
Shaw_price_indices5b_2$den[Year<=1906 | Year==1910] <- p1_1913[Year<=1906 | Year==1910]*q1_1913[Year<=1906 | Year==1910] + p2_1913[Year<=1906 | Year==1910]*q2_1913[Year<=1906 | Year==1910]
Shaw_price_indices5b_2$den[Year<=1909 & Year>=1907] <- p1_1913[Year<=1909 & Year>=1907]*q1_1913[Year<=1909 & Year>=1907] + p2_1913[Year<=1909 & Year>=1907]*q2_1913[Year<=1909 & Year>=1907] + p3_1913[Year<=1909 & Year>=1907]*q3_1913[Year<=1909 & Year>=1907]
Shaw_price_indices5b_2$den[Year<=1919 & Year>=1911] <- p1_1913[Year<=1919 & Year>=1911]*q1_1913[Year<=1919 & Year>=1911] + p2_1913[Year<=1919 & Year>=1911]*q2_1913[Year<=1919 & Year>=1911] + p3_1913[Year<=1919 & Year>=1911]*q3_1913[Year<=1919 & Year>=1911]
detach(Shaw_price_indices5b_2)
Shaw_price_indices5b_2$price5b_shaw=100*Shaw_price_indices5b_2$num/Shaw_price_indices5b_2$den
Shaw_price_indices5b_3 <- subset(Shaw_price_indices5b_2,select=c("Year","price5b_shaw"))

Kuznets_5b_Coal <- read.csv("Kuznets_5b_Coal.csv",skip=1)
Kuznets_5b_Coal$price5b_kuznets <- 100*Kuznets_5b_Coal$Current.Prices/Kuznets_5b_Coal$X1929.Prices
Shaw_price_indices5b <- merge(Shaw_price_indices5b_3,Kuznets_5b_Coal,by="Year",all.x=TRUE,all.y=TRUE)

Shaw_price_indices5b_1919_values <- subset(Shaw_price_indices5b,Year==1919)
varnames_keep <- names(Shaw_price_indices5b_1919_values) %in% c("Year","price5b_shaw","price5b_kuznets")
Shaw_price_indices5b_1919_values <- Shaw_price_indices5b_1919_values[varnames_keep]

tmp <- Shaw_price_indices5b_1919_values
for(i in 1:(1929-1899)){ 	
	Shaw_price_indices5b_1919_values <- rbind(Shaw_price_indices5b_1919_values,tmp)
}
Shaw_price_indices5b_1919_values$Year <- 1899:1929
Shaw_price_indices5b_1919_values <- rename(Shaw_price_indices5b_1919_values,c(price5b_shaw="price5b_shaw_1919",price5b_kuznets="price5b_kuznets_1919"))
Shaw_price_indices5b <- merge(Shaw_price_indices5b,Shaw_price_indices5b_1919_values,by="Year")
attach(Shaw_price_indices5b)
Shaw_price_indices5b$price5b_pre1919 <- price5b_kuznets_1919*price5b_shaw/price5b_shaw_1919
detach(Shaw_price_indices5b)

attach(Shaw_price_indices5b)
Shaw_price_indices5b$price5b[Year<=1918] <- price5b_pre1919[Year<=1918]
Shaw_price_indices5b$price5b[Year>=1919] <- price5b_kuznets[Year>=1919]
detach(Shaw_price_indices5b)
Shaw_price_indices5b <- subset(Shaw_price_indices5b,select=c("Year","price5b"))

Shaw_price_indices <- merge(Shaw_price_indices1a_5a,Shaw_price_indices5b,by="Year")

# convert price indices to 1929 prices and domestic consumption from current to 1929 prices

Shaw_price_indices_1929_values <- subset(Shaw_price_indices,Year==1929)
varnames_drop <- names(Shaw_price_indices_1929_values) %in% c("Year")
Shaw_price_indices_1929_values <- Shaw_price_indices_1929_values[!varnames_drop]

tmp <- Shaw_price_indices_1929_values
for(i in 1:(1929-1899)){ 	
	Shaw_price_indices_1929_values <- rbind(Shaw_price_indices_1929_values,tmp)
}
Shaw_price_indices_1929_values$Year <- 1899:1929
Shaw_price_indices_1929_values <- rename(Shaw_price_indices_1929_values,c(price1="price1_1929",price2="price2_1929",price3="price3_1929",price4="price4_1929",price5a="price5a_1929",price5b="price5b_1929"))
Shaw_price_indices <- merge(Shaw_price_indices,Shaw_price_indices_1929_values,by="Year")

attach(Shaw_price_indices)
Shaw_price_indices$price1=100*price1/price1_1929
Shaw_price_indices$price2=100*price2/price2_1929
Shaw_price_indices$price3=100*price3/price3_1929
Shaw_price_indices$price4=100*price4/price4_1929
Shaw_price_indices$price5a=100*price5a/price5a_1929
Shaw_price_indices$price5b=100*price5b/price5b_1929
detach(Shaw_price_indices)

varnames_drop <- names(Shaw_price_indices) %in% c("price1_1929","price2_1929","price3_1929","price4_1929","price5a_1929","price5b_1929")
Shaw_price_indices <- Shaw_price_indices[!varnames_drop]

Shaw_Perishables <- merge(Shaw_Perishables,Shaw_price_indices,by="Year")

attach(Shaw_Perishables)
Shaw_Perishables$cons_real1a = 100*Shaw_Perishables$cons1a/Shaw_Perishables$price1
Shaw_Perishables$cons_real1b = 100*Shaw_Perishables$cons1b/Shaw_Perishables$price1
Shaw_Perishables$cons_real2 = 100*Shaw_Perishables$cons2/Shaw_Perishables$price2
Shaw_Perishables$cons_real3 = 100*Shaw_Perishables$cons3/Shaw_Perishables$price3
Shaw_Perishables$cons_real4 = 100*Shaw_Perishables$cons4/Shaw_Perishables$price4
Shaw_Perishables$cons_real5a = 100*Shaw_Perishables$cons5a/Shaw_Perishables$price5a
Shaw_Perishables$cons_real5b = 100*Shaw_Perishables$cons5b/Shaw_Perishables$price5b
detach(Shaw_Perishables)

# export results
shaw_perishables <- Shaw_Perishables
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
save(shaw_perishables,file="s003.shaw_perishables.RData")

