#!/usr/bin/env Rscript
rm(list=ls()[!grepl('^rootpath$',ls())])
setwd(paste(rootpath,"Analysis/Input",sep=""))
getwd()

# import gross farm income from 1899 - 1913
farm_income <- read.csv("Farm_Income.csv",skip=0)
attach(farm_income)
farm_income$farm_income <- Wheat..rye..potatoes..sweet.potatoes..dry.beans..rice+Orchard..Citrus..grapes+Dairy.Products..Chicken.and.Eggs+Cattle..calves..hogs..sheep.and.lambs
detach(farm_income)
farm_income$farm_income_domestic <- farm_income$farm_income - (1-0.1)*farm_income$Export.of.Crude.Food # For 10% deduction for exporter's expenses, see Shaw (1947) page 271.
farm_income <- subset(farm_income,select=c("Year","farm_income_domestic"))

HSUT_Da1351_1356 <- read.csv("HSUT_Da1351_1356.csv",skip=0)
HSUT_Da1351_1356_1947 <- subset(HSUT_Da1351_1356,Year==1947)
adj1 <- HSUT_Da1351_1356_1947[[2,5]]/HSUT_Da1351_1356_1947[[1,5]]
adj2 <- HSUT_Da1351_1356_1947[[2,2]]/HSUT_Da1351_1356_1947[[1,2]]

farm_food <- by(HSUT_Da1351_1356,HSUT_Da1351_1356$Year,head,n=1)
farm_food <- do.call("rbind",as.list(farm_food))
farm_food <- subset(farm_food,select=c("Year","Total","Farm.value"))
attach(farm_food)
farm_food$Farm.value[Year<=1947 & Year>=1913]=adj1*Farm.value[Year<=1947 & Year>=1913]
farm_food$Total[Year<=1947 & Year>=1913]=adj2*Total[Year<=1947 & Year>=1913]
detach(farm_food)
attach(farm_food)
farm_food$mkt.bill=Total/Farm.value
detach(farm_food)
farm_food$mkt.bill_LEAD <- c(tail(farm_food$mkt.bill,-1),NA)
farm_food$Farm.value_LEAD <- c(tail(farm_food$Farm.value,-1),NA)
attach(farm_food)
farm_food$mkt.bill_grw=log(mkt.bill_LEAD/mkt.bill)
farm_food$Farm.value_grw=log(Farm.value_LEAD/Farm.value)
detach(farm_food)

farm_food <- subset(farm_food,Year<=1996)
food_regression <- lm(farm_food$mkt.bill_grw ~ farm_food$Farm.value_grw)

farm_food <- merge(farm_food,farm_income,by="Year",all=TRUE)
farm_food$farm_income_domestic_adj <- farm_food[[15,3]]/farm_food[[15,9]]*farm_food$farm_income_domestic
attach(farm_food)
farm_food$Farm.value[Year <= 1912] <- farm_income_domestic_adj[Year<=1912]
detach(farm_food)
farm_food$Farm.value_LEAD <- c(tail(farm_food$Farm.value,-1),NA)
attach(farm_food)
farm_food$Farm.value_grw=log(Farm.value_LEAD/Farm.value)
detach(farm_food)
farm_food$mkt.bill_grw <- food_regression$coefficient[[1]]+food_regression$coefficient[[2]]*farm_food$Farm.value_grw

for (t in (15:2)){
	farm_food$mkt.bill[[t-1]]=farm_food$mkt.bill[[t]]/exp(farm_food$mkt.bill_grw[[t-1]])
}
	
farm_food$mkt.bill_grw_LAG <- c(head(farm_food$mkt.bill_grw,-1),NA)
attach(farm_food)
farm_food$Total[Year<=1912] <- farm_food$Farm.value[Year<=1912]*farm_food$mkt.bill[Year<=1912] 
detach(farm_food)

Retail_Price_Food_1899_1929 <- read.csv("Retail_Price_Food_1899_1929.csv",skip=0)
price_retail_1929_value <- Retail_Price_Food_1899_1929[[31,2]]
Retail_Price_Food_1899_1929$price_retail_food_1929 <- 100*(1/price_retail_1929_value)*Retail_Price_Food_1899_1929$Retail.Price.Index.for.Food..BLS..1913...100
Retail_Price_Food_1899_1929 <- subset(Retail_Price_Food_1899_1929,select=c("Year","price_retail_food_1929"))
farm_food <- merge(farm_food,Retail_Price_Food_1899_1929,by="Year")
farm_food$cons_farm_food_real <- 100*farm_food$Total/farm_food$price_retail_food_1929
farm_food <- rename(farm_food,c(Total="cons_farm_food_nom"))

# export results
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
sink(file="s005.food_regression.txt")
summary(food_regression)
sink(NULL)
save(farm_food,file="s005.farm_food.RData")

