#!/usr/bin/env Rscript
rm(list=ls()[!grepl('^rootpath$',ls())])
# export results
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
load("s003.shaw_perishables.RData")

# incorporate the value added by transportation and distribution, adjusted for inventory changes - based on kuznets methodology
shaw_tbl_ii_1_nonfood <- subset(shaw_perishables,select=c("Year","cons2","cons3","cons4","cons5a","cons5b","cons_real2","cons_real3","cons_real4","cons_real5a","cons_real5b"))

attach(shaw_tbl_ii_1_nonfood)
shaw_tbl_ii_1_nonfood$cons2_5a = (1/1000)*(cons2+cons3+cons4+cons5a+cons5b)
shaw_tbl_ii_1_nonfood$cons_real2_5a = (1/1000)*(cons_real2+cons_real3+cons_real4+cons_real5a+cons_real5b)
detach(shaw_tbl_ii_1_nonfood)

shaw_tbl_ii_1_nonfood$cons_real2_5a_retail = 1.5001*shaw_tbl_ii_1_nonfood$cons_real2_5a # see notes to column 3 and lines 1-13, table ii 1, kuznets (1946)
shaw_tbl_ii_1_nonfood$cons_real2_5a_retail_LEAD=c(tail(shaw_tbl_ii_1_nonfood$cons_real2_5a_retail,-1),NA)
shaw_tbl_ii_1_nonfood$net_chg_inventory <- (shaw_tbl_ii_1_nonfood$cons_real2_5a_retail_LEAD-shaw_tbl_ii_1_nonfood$cons_real2_5a_retail)

shaw_tbl_1899_1908 <- subset(shaw_tbl_ii_1_nonfood,Year>=1899 & Year<=1908)
shaw_tbl_decade_avg_1899_1908 <- mean(shaw_tbl_1899_1908)
shaw_tbl_1904_1913 <- subset(shaw_tbl_ii_1_nonfood,Year>=1904 & Year<=1913)
shaw_tbl_decade_avg_1904_1913 <- mean(shaw_tbl_1904_1913)
shaw_tbl_1909_1918 <- subset(shaw_tbl_ii_1_nonfood,Year>=1909 & Year<=1918)
shaw_tbl_decade_avg_1909_1918 <- mean(shaw_tbl_1909_1918)
shaw_tbl_decade_avg <- data.frame(rbind(shaw_tbl_decade_avg_1899_1908,shaw_tbl_decade_avg_1904_1913,shaw_tbl_decade_avg_1909_1918))
attach(shaw_tbl_decade_avg)
shaw_tbl_decade_avg$cons_real2_5a_retail = 1.5001*cons_real2_5a # see notes to column 3 and lines 1-13, table ii 1, kuznets (1946)
shaw_tbl_decade_avg$net_chg_inventory = 0.1587*net_chg_inventory # see notes to column 4 and lines 1-13, table ii 1, kuznets (1946)
detach(shaw_tbl_decade_avg)
attach(shaw_tbl_decade_avg)
shaw_tbl_decade_avg$cons_real2_5a_final = cons_real2_5a_retail - net_chg_inventory
shaw_tbl_decade_avg$price1 = 100*cons2_5a/cons_real2_5a 
detach(shaw_tbl_decade_avg)
shaw_tbl_decade_avg$cons2_5a_final = (1/100)*(shaw_tbl_decade_avg$cons_real2_5a_final*shaw_tbl_decade_avg$price1)
shaw_tbl_decade_avg$ratios = shaw_tbl_decade_avg$cons_real2_5a_final/shaw_tbl_decade_avg$cons_real2_5a

shaw_tbl_r_28_nonfood <- subset(shaw_perishables,select=c("Year","cons2","cons3","cons4","cons5a","cons5b","cons_real2","cons_real3","cons_real4","cons_real5a","cons_real5b"))
attach(shaw_tbl_r_28_nonfood)
shaw_tbl_r_28_nonfood$cons2_5a = (1/1000)*(cons2+cons3+cons4+cons5a+cons5b)
shaw_tbl_r_28_nonfood$cons_real2_5a = (1/1000)*(cons_real2+cons_real3+cons_real4+cons_real5a+cons_real5b)
detach(shaw_tbl_r_28_nonfood)

extrap <- lm(shaw_tbl_decade_avg$ratios ~ shaw_tbl_decade_avg$Year)
shaw_tbl_r_28_nonfood$ratio_extrap <- extrap$coefficients[[2]]*shaw_tbl_r_28_nonfood$Year+extrap$coefficients[[1]]
shaw_tbl_r_28_nonfood$cons_real_final_var_i_2_5a <- shaw_tbl_r_28_nonfood$cons_real2_5a*shaw_tbl_r_28_nonfood$ratio_extrap

shaw_tbl_r_28_nonfood$cons_real_final_var_iii_2_5a <- mean(c(27245,26518,26497))/mean(c(27963,27456,26234))*shaw_tbl_r_28_nonfood$cons_real_final_var_i_2_5a # ratio of: (1) average flow of perishable goods to consumers at cost to them, 1929 prices, variant iii, for 1929-1931; to (2) average flow of perishable goods to consumers at cost to them, 1929 prices, variant i, for 1929-1931. for flow of perishable goods to consumers at cost to them, 1929 prices, variant iii and i, see table t-7, pg. 13, technical tables underlying series in capital in american economy: its formation anf financing.

shaw_tbl_r_28_nonfood$price2_5a=shaw_tbl_r_28_nonfood$cons2_5a/shaw_tbl_r_28_nonfood$cons_real2_5a
shaw_tbl_r_28_nonfood$cons_final_var_iii_2_5a=shaw_tbl_r_28_nonfood$price2_5a*shaw_tbl_r_28_nonfood$cons_real_final_var_iii_2_5a

# export results
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
save(shaw_tbl_r_28_nonfood,file="s007.shaw_tbl_r_28_nonfood.RData")

