#!/usr/bin/env Rscript
rm(list=ls()[!grepl('^rootpath$',ls())])
library(plyr)
library(reshape)
library(gdata)
setwd(paste(rootpath,"Analysis/Code",sep=""))
getwd()
source("hp.r")

# data for price index regression
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
load("s010.azeredo_nipa_nominal_v1.RData")
load("s009.azeredo_nipa_real_v1.RData")

azeredo_nipa_real_v1 <- subset(azeredo_nipa_real_v1,select=c("Year","CND_AZE_LVL","CS_AZE_LVL"))
azeredo_nipa_nominal_v1 <- subset(azeredo_nipa_nominal_v1,select=c("Year","NCND_AZE_LVL","NCS_AZE_LVL"))
azeredo_nipa_prices_v1 <- merge(azeredo_nipa_real_v1,azeredo_nipa_nominal_v1,by="Year")

attach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1$PCND_AZE_2005 <- 100*NCND_AZE_LVL/CND_AZE_LVL
azeredo_nipa_prices_v1$PCS_AZE_2005 <- 100*NCS_AZE_LVL/CS_AZE_LVL
detach(azeredo_nipa_prices_v1)
attach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1$PCND_AZE_2005_LOG <- log(PCND_AZE_2005)
azeredo_nipa_prices_v1$PCS_AZE_2005_LOG <- log(PCS_AZE_2005)
detach(azeredo_nipa_prices_v1)

azeredo_nipa_prices_v1$PCND_AZE_2005_HP <- hp(azeredo_nipa_prices_v1$PCND_AZE_2005_LOG,100)
attach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1$PCS_AZE_2005_HP[Year>=1929] <- hp(PCS_AZE_2005_LOG[Year>=1929],100)
detach(azeredo_nipa_prices_v1)

# trend line for price index
setwd(paste(rootpath,"Analysis/Input",sep=""))
getwd()
Kuz_Curr_VIII <- read.csv("Kuz_Curr_VIII.csv",skip=0)
Kuz_Curr_VIII <- subset(Kuz_Curr_VIII,Year<=1929)
attach(Kuz_Curr_VIII)
Kuz_Curr_VIII$Service_Adj_Nom <- Services+Kendrick.Adjustment
detach(Kuz_Curr_VIII)
Kuz_Curr_VIII <- subset(Kuz_Curr_VIII,select=c("Year","Service_Adj_Nom"))

Kuz_1929_VIII <- read.csv("Kuz_1929_VIII.csv",skip=0)
Kuz_1929_VIII <- subset(Kuz_1929_VIII,Year<=1929)
attach(Kuz_1929_VIII)
Kuz_1929_VIII$Service_Adj_Real <- Services+Kendrick.Adjustment
detach(Kuz_1929_VIII)
Kuz_1929_VIII <- subset(Kuz_1929_VIII,select=c("Year","Service_Adj_Real"))

Kuz_PriceIndex_VIII <- merge(Kuz_Curr_VIII,Kuz_1929_VIII,by="Year")
attach(Kuz_PriceIndex_VIII)
Kuz_PriceIndex_VIII$Service_Price_Index_1929 <- Service_Adj_Nom/Service_Adj_Real
detach(Kuz_PriceIndex_VIII)
PCS_AZE_2005_Year_eq_1929 <- subset(subset(azeredo_nipa_prices_v1,Year==1929),select=c("PCS_AZE_2005"))
Kuz_PriceIndex_VIII$Service_Price_Index_2005 <- PCS_AZE_2005_Year_eq_1929$PCS_AZE_2005*Kuz_PriceIndex_VIII$Service_Price_Index_1929
Kuz_PriceIndex_VIII$Service_Price_Index_2005_LOG <- log(Kuz_PriceIndex_VIII$Service_Price_Index_2005)
Kuz_PriceIndex_VIII <- subset(Kuz_PriceIndex_VIII,Year>=1899)
Kuz_PriceIndex_VIII$Service_Price_Index_2005_HP <- hp(Kuz_PriceIndex_VIII$Service_Price_Index_2005_LOG,100)
Kuz_PriceIndex_VIII <- subset(Kuz_PriceIndex_VIII,select=c("Year","Service_Price_Index_2005_HP"))

azeredo_nipa_prices_v1 <- merge(azeredo_nipa_prices_v1,Kuz_PriceIndex_VIII,by="Year",all.x=TRUE,all.y=TRUE)

attach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1$PCS_AZE_2005_HP[Year<=1928] <- (PCS_AZE_2005_HP[Year==1929]/Service_Price_Index_2005_HP[Year==1929])*Service_Price_Index_2005_HP[Year<=1928] 
detach(azeredo_nipa_prices_v1)
attach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1$PCS_AZE_DIFF <- azeredo_nipa_prices_v1$PCS_AZE_2005_LOG - azeredo_nipa_prices_v1$PCS_AZE_2005_HP
detach(azeredo_nipa_prices_v1)

# create first difference and lags for non-durables
attach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1$PCND_AZE_DIFF <- PCND_AZE_2005_LOG - PCND_AZE_2005_HP 
detach(azeredo_nipa_prices_v1)
price_index_backcasting <- subset(azeredo_nipa_prices_v1,select=c("Year","PCND_AZE_DIFF"))
price_index_backcasting$PCND_AZE_DIFF_LEAD=c(tail(price_index_backcasting$PCND_AZE_DIFF,-1),NA)
attach(price_index_backcasting)
price_index_backcasting$PCND_AZE_FIRSTDIFF = PCND_AZE_DIFF_LEAD - PCND_AZE_DIFF
detach(price_index_backcasting)
attach(price_index_backcasting)
price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG1 = c(NA,head(PCND_AZE_FIRSTDIFF,-1))
detach(price_index_backcasting)
attach(price_index_backcasting)
price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG2 = c(NA,head(PCND_AZE_FIRSTDIFF_LAG1,-1))
detach(price_index_backcasting)
attach(price_index_backcasting)
price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG1[Year==2009] <- NA
price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG2[Year==2009] <- NA
detach(price_index_backcasting)
m1 <- mean(price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG1,na.rm=TRUE)
attach(price_index_backcasting)
price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG1[Year==1899] <- m1
price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG2[Year==1900] <- m1
detach(price_index_backcasting)

m2 <- mean(price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG2,na.rm=TRUE)
attach(price_index_backcasting)
price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG2[Year==1899] <- m2
detach(price_index_backcasting)

price_index_backcasting1 <- subset(azeredo_nipa_prices_v1,select=c("Year","PCS_AZE_DIFF"))
price_index_backcasting1$PCS_AZE_DIFF_LEAD=c(tail(price_index_backcasting1$PCS_AZE_DIFF,-1),NA)
attach(price_index_backcasting1)
price_index_backcasting1$PCS_AZE_FIRSTDIFF = PCS_AZE_DIFF_LEAD - PCS_AZE_DIFF
detach(price_index_backcasting1)

price_index_backcasting <- merge(price_index_backcasting,price_index_backcasting1,by="Year",all.x=TRUE,all.y=TRUE)

service_price_index_regression <- lm(price_index_backcasting$PCS_AZE_FIRSTDIFF ~ price_index_backcasting$PCND_AZE_FIRSTDIFF + price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG1 + price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG2)

price_index_backcasting$PCS_AZE_FIRSTDIFF_HAT <- service_price_index_regression$coefficient[[1]]+service_price_index_regression$coefficient[[2]]*price_index_backcasting$PCND_AZE_FIRSTDIFF+service_price_index_regression$coefficient[[3]]*price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG1+service_price_index_regression$coefficient[[4]]*price_index_backcasting$PCND_AZE_FIRSTDIFF_LAG2
attach(price_index_backcasting)
price_index_backcasting$PCS_AZE_FIRSTDIFF[Year<1929] <- PCS_AZE_FIRSTDIFF_HAT[Year<1929]
detach(price_index_backcasting)
for (t in (31:2)){
	price_index_backcasting$PCS_AZE_DIFF[[t-1]] <- price_index_backcasting$PCS_AZE_DIFF[[t]] - price_index_backcasting$PCS_AZE_FIRSTDIFF[[t-1]] 
}

price_index_backcasting <- subset(price_index_backcasting,select=c("Year","PCS_AZE_DIFF"))
azeredo_nipa_prices_v1 <- subset(azeredo_nipa_prices_v1,select=c("Year","PCND_AZE_2005","PCS_AZE_2005","PCS_AZE_2005_HP"))
azeredo_nipa_prices_v1 <- merge(azeredo_nipa_prices_v1,price_index_backcasting,by="Year",all.x=TRUE,all.y=TRUE)

attach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1$PCS_AZE_2005[Year<=1928] <- exp(PCS_AZE_2005_HP[Year<=1928]+PCS_AZE_DIFF[Year<=1928])
detach(azeredo_nipa_prices_v1)
azeredo_nipa_prices_v1 <- subset(azeredo_nipa_prices_v1,select=c("Year","PCND_AZE_2005","PCS_AZE_2005"))

# export results
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
sink(file="s011.service_price_index_regression.txt")
summary(service_price_index_regression)
sink(NULL)
save(azeredo_nipa_prices_v1,file="s011.azeredo_nipa_prices_v1.RData")

azeredo <- merge(azeredo_nipa_real_v1,azeredo_nipa_prices_v1,by="Year",all.x=TRUE,all.y=TRUE)
azeredo <- merge(azeredo,azeredo_nipa_nominal_v1,by="Year",all.x=TRUE,all.y=TRUE)

attach(azeredo)
azeredo$CS_AZE_LVL[Year<=1928] <- 100*NCS_AZE_LVL[Year<=1928]/PCS_AZE_2005[Year<=1928] 
detach(azeredo)

# import population, merge, compute per capita and growth
setwd(paste(rootpath,"Analysis/Input",sep=""))
getwd()
POP1 <- read.csv("POP1.csv",skip=5)
POP1 <- subset(rename(POP1,c(X="Year",Thousand="pop")), select=c("Year","pop"))
POP1 <- subset(POP1,Year<=2000)

POP2 <- read.csv("POP2.csv",skip=0)
POP2 <- subset(POP2,Year>=2001)
POP2$pop = POP2$pop/1000

POP <- rbind(POP1,POP2)
POP$pop = POP$pop/1000

# per capita growth rates
azeredo <- merge(azeredo,POP,by="Year")
azeredo$CNDPER_AZE_LVL = 1000*azeredo$CND_AZE_LVL/azeredo$pop
azeredo$CSPER_AZE_LVL = 1000*azeredo$CS_AZE_LVL/azeredo$pop

azeredo$CNDPER_AZE_LVL_LEAD=c(tail(azeredo$CNDPER_AZE_LV,-1),NA)
azeredo$CNDPER_AZE_GRW=azeredo$CNDPER_AZE_LVL_LEAD/azeredo$CNDPER_AZE_LVL-1

azeredo$CSPER_AZE_LVL_LEAD=c(tail(azeredo$CSPER_AZE_LV,-1),NA)
azeredo$CSPER_AZE_GRW=azeredo$CSPER_AZE_LVL_LEAD/azeredo$CSPER_AZE_LVL-1

azeredo$NCND_AZE_SHR=azeredo$NCND_AZE_LVL/(azeredo$NCND_AZE_LVL+azeredo$NCS_AZE_LVL)
azeredo$NCS_AZE_SHR=azeredo$NCS_AZE_LVL/(azeredo$NCND_AZE_LVL+azeredo$NCS_AZE_LVL)

attach(azeredo)
azeredo$CNDSPER_AZE_GRW[Year<=1928] <- (CNDPER_AZE_LVL_LEAD[Year<=1928]+CSPER_AZE_LVL_LEAD[Year<=1928])/(CNDPER_AZE_LVL[Year<=1928]+CSPER_AZE_LVL[Year<=1928])-1
azeredo$CNDSPER_AZE_GRW[Year>1928] <- CNDPER_AZE_GRW[Year>1928]*NCND_AZE_SHR[Year>1928]+CSPER_AZE_GRW[Year>1928]*NCS_AZE_SHR[Year>1928]
detach(azeredo)

azeredo$NCNDPER_AZE_LVL = 1000*azeredo$NCND_AZE_LVL/azeredo$pop
azeredo$NCSPER_AZE_LVL = 1000*azeredo$NCS_AZE_LVL/azeredo$pop

azeredo$NCNDPER_AZE_LVL_LEAD=c(tail(azeredo$NCNDPER_AZE_LVL,-1),NA)
azeredo$NCNDPER_AZE_GRW=azeredo$NCNDPER_AZE_LVL_LEAD/azeredo$NCNDPER_AZE_LVL-1

azeredo$NCSPER_AZE_LVL_LEAD=c(tail(azeredo$NCSPER_AZE_LV,-1),NA)
azeredo$NCSPER_AZE_GRW=azeredo$NCSPER_AZE_LVL_LEAD/azeredo$NCSPER_AZE_LVL-1

azeredo$NCNDSPER_AZE_GRW=(azeredo$NCNDPER_AZE_LVL_LEAD+azeredo$NCSPER_AZE_LVL_LEAD)/(azeredo$NCNDPER_AZE_LVL+azeredo$NCSPER_AZE_LVL)-1

azeredo$CND_AZE_LVL_LEAD=c(tail(azeredo$CND_AZE_LVL,-1),NA)
azeredo$CND_AZE_GRW=azeredo$CND_AZE_LVL_LEAD/azeredo$CND_AZE_LVL-1

azeredo$CS_AZE_LVL_LEAD=c(tail(azeredo$CS_AZE_LVL,-1),NA)
azeredo$CS_AZE_GRW=azeredo$CS_AZE_LVL_LEAD/azeredo$CS_AZE_LVL-1

azeredo <- azeredo[,-grep("_LEAD$", names(azeredo))]
azeredo <- azeredo[,-grep("_SHR$", names(azeredo))]

# export results
setwd(paste(rootpath,"Analysis/Output",sep=""))
getwd()
save(azeredo,file="s011.azeredo.RData")

write.table(azeredo,"s011.consumption_final.csv",sep=",")

